all.Cycsm<-function(){
     cat("\n")
     note_for_Cycsm_input()
     cat("\n")
     note_for_close_window()
     CycSMMpar<-data.frame(parameter=c("bw (kg)","PTD (day)","Dia","D (mg)","tau (hr)"),value=c(0))
     CycSMMpar<-edit(CycSMMpar)
##     CycSMMpar<-zcheck(CycSMMpar)
     cat("\n")
     note_for_Cycsm_conc_input()
     cat("\n")
     note_for_close_window()
     CycSMpar<-data.frame(ts=c(0),conc=c(0))
     CycSMpar<-edit(CycSMpar)
##     CycSMpar<-mscheck(CycSMpar)
     cat("\n")
     Cyc.sm(length(CycSMpar$ts),CycSMpar$conc,CycSMpar$ts,CycSMMpar[2,2],CycSMMpar[5,2],CycSMMpar[4,2],CycSMMpar[1,2],CycSMMpar[3,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Cycsm_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Cyccpr(CycSMMpar[2,2],CycSMMpar[1,2],CycSMMpar[4,2],CycSMMpar[5,2],CycSMMpar[5,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput)    
     cat("\n")    
     Cyc.more(CycSMMpar[2,2],CycSMMpar[1,2])
}